@@ -1,13 +1,13 @@
 # copy lib:
-libfile <- paste0("stringi", SHLIB_EXT)
-dest <- file.path(R_PACKAGE_DIR, paste0("libs", R_ARCH))
+libfile <- paste("stringi", SHLIB_EXT, sep="")
+dest <- file.path(R_PACKAGE_DIR, paste("libs", R_ARCH, sep=""))
 dir.create(dest, recursive=TRUE, showWarnings=FALSE)
 file.copy(libfile, dest, overwrite=TRUE)
 
 # copy icudt when building ICU from sources
 copyicudt <- TRUE
-if (file.exists('icu52_found.txt')) {
-   copyicudt <- !as.logical(as.numeric(readChar('icu52_found.txt', 1)))
+if (file.exists('icu55_found.txt')) {
+   copyicudt <- !as.logical(as.numeric(readChar('icu55_found.txt', 1)))
    if (is.na(copyicudt)) copyicudt <- TRUE
 }
 
@@ -16,7 +16,8 @@ if (copyicudt) {
    outdir <- file.path(R_PACKAGE_DIR, "libs")
    if (length(dir(outdir, pattern=glob2rx("*.dat"))) == 0) {
       # avoids multiple download attempts while multiarch building
-      stri_install_icudt(FALSE, outdir, "icu52/data/")
+      if (!stri_install_icudt(FALSE, outdir, "icu55/data"))
+         stop("icudt could not be downloaded. check your internet connectivity")
    }
 # Note that if the data file is not found, some features will
 # be unavailable (but the package itself will load properly,
