@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (c) 2013-2014, Marek Gagolewski and Bartek Tartanus
+ * Copyright (C) 2013-2015, Marek Gagolewski and Bartek Tartanus
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -314,8 +314,8 @@ const char* StriException::getICUerrorName(UErrorCode status)
             return "Look-Behind pattern matches must have a bounded maximum length.";
          case U_REGEX_SET_CONTAINS_STRING:
             return "Regexps cannot have UnicodeSets containing strings.";
-         case U_REGEX_OCTAL_TOO_BIG:
-            return "Octal character constants must be <= 0377.";
+//         case U_REGEX_OCTAL_TOO_BIG: //Deprecated ICU 54. This error cannot occur.
+//            return "Octal character constants must be <= 0377.";
          case U_REGEX_MISSING_CLOSE_BRACKET:
             return "Missing closing bracket on a bracket expression.";
          case U_REGEX_INVALID_RANGE:
